@@ -84,6 +84,12 @@ class ImmutableDict(object):
         except KeyError: return False
 
     def __eq__(self, other):
+        if other is None:
+            return False
+
+        if not hasattr(other, '__getitem__'):
+            return False
+
         if len(self) != len(other):
             return False
 
@@ -93,6 +99,9 @@ class ImmutableDict(object):
 
         return True
 
+    def __ne__(self, other):
+        return not self.__eq__(other)
+
 def iter_length(iterable):
     try:
         return len(iterable)
